/**
 * @file        json_util.h
 * @brief       Utility for json data, it extracts value from json

 * Copyright (c) 2017 Samsung Electronics Co., Ltd.
 * This software is the confidential and proprietary information
 * of Samsung Electronics, Inc. ("Confidential Information"). You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Samsung.
 */

#ifndef __JSON_UTIL_H__
#define __JSON_UTIL_H__

#include <json.h>

/**
 * @fn        char *json_getString(char *data, char *key)
 * @brief     this function to get string from key in json data
 * @param     data          [in] json data
 * @param     key           [in] key for finding value
 * @return    *char    value of key
 */
char *json_getString(char *data, char *key);
/**
 * @fn        char *json_getObject(char *data, char *key)
 * @brief     this function to get object from key in json data
 * @param     data          [in] json data
 * @param     key           [in] key for finding value
 * @return    *char  object of key
 */
char *json_getObject(char *data, char *key);
/**
 * @fn        int json_getNumber(char *data, char *key)
 * @brief     this function to get number from key in json data
 * @param     data          [in] json data
 * @param     key           [in] key for finding value
 * @return    int    number of key
 */
int json_getNumber(char *data, char *key);
/**
 * @fn        char *json_getArray(char *data, char *key)
 * @brief     this function to get array from key in json data
 * @param     data          [in] json data
 * @param     key           [in] key for finding value
 * @return    *char    array json of key
 */
char *json_getArray(char *data, char *key);
/**
 * @fn        int json_getArrayLength(char *data)
 * @brief     this function to get number of array from key in json data
 * @param     data          [in] json data
 * @param     key           [in] key for finding value
 * @return    int     array count of key
 */
int json_getArrayLength(char *data);
/**
 * @fn        char *json_getStringFromArray(char *data, char *arrayKey, int arrayIndex, char *key)
 * @brief     this function to get string from array json data
 * @param     data          [in] json data
 * @param     arrayKey      [in] array key for value
 * @param     arrayIndex    [in] index of array
 * @param     key           [in] key for finding value
 * @return    *char  string of key
 */
char *json_getStringFromArray(char *data, char *arrayKey, int arrayIndex, char *key);

/**
 * @fn       double json_getDoubleFromArray(char *data, char *arrayKey, int arrayIndex, char *key)
 * @brief     this function to get double floating point from array json data
 * @param     data          [in] json data
 * @param     arrayKey      [in] array key for value
 * @param     arrayIndex    [in] index of array
 * @param     key           [in] key for finding value
 * @return    double  double floating point of key
 */
double json_getDoubleFromArray(char *data, char *arrayKey, int arrayIndex, char *key);

/**
 * @fn       int json_getIntFromArray(char *data, char *arrayKey, int arrayIndex, char *key)
 * @brief     this function to get double floating point from array json data
 * @param     data          [in] json data
 * @param     arrayKey      [in] array key for value
 * @param     arrayIndex    [in] index of array
 * @param     key           [in] key for finding value
 * @return    integer  integer value of key
 */
int json_getIntFromArray(char *data, char *arrayKey, int arrayIndex, char *key);

#endif /* __JSON_UTIL_H__ */
